Port
====

.. _Port_Subtypes:
.. container:: subclasses

    *Subclasses*

    .. toctree::
       :maxdepth: 1

       InputPort
       ParameterPort
       OutputPort
       ModulatorySignal

.. automodule:: psyneulink.core.components.ports.port
   :members:
   :private-members:
   :exclude-members: random, update, Parameters

